<?php

namespace Teknisa\EST\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;


class Est57000TransferenciaEstoqueController extends \Teknisa\EST\Controllers\TeknisaCrud {
	protected $dataSourceName = '';
	protected $dataSourceNameSave = '';
	protected $parameterBagColumns = array('');
    protected $est57000transferenciaestoqueservice;

    public function __construct($crudService, $parameterBag,$est57000transferenciaestoqueservice) {
        parent::__construct($crudService, $parameterBag);
        $this->est57000transferenciaestoqueservice = $est57000transferenciaestoqueservice;
    }

	public function find(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $rota = $request->getRoutePath();
            $name = substr($rota,1);
            switch ($name) {
                case 'ctrlmoviestq_transferenciaEstoque':
                    $this->parameterBagColumns =  array("P_CDFILIAL","P_CDALMOXDEST","P_CDALMOXORIG","P_CDLOCALDEST","P_CDLOCALORIG","P_DTLANCINI","P_DTLANCFIN","P_DATA");
                    break;
                case 'itlanctoest_produto_itrequesto':
                    $this->parameterBagColumns =  array("P_CDFILIAL","P_NRLANCESTQ");
                    break;
                case 'requesto_itrequesto_transferenciaesotque':
                    $this->parameterBagColumns =  array("CDFILIAL");
                    break;
                default:
                    $this->parameterBagColumns =  array("");
                    break;
            }

            $this->dataSourceName = $name;
            parent::find($request,$response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function buscaDataProcessamento(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $data = $this->est57000transferenciaestoqueservice->buscaDataProcessamento($row);
            $dataSet = new DataSet('dataProcessamento', $data);
            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function editTransferencia(DTO\Request $request, DTO\Response $response) {
        try {
            $this->dataSourceName ='ctrlmoviestq_transferenciaEstoque';
            $this->dataSourceNameToSave = 'ctrlmoviestq';
            parent::save($request,$response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function salvarNovaTransferencia(DTO\Request $request, DTO\Response $response) {
        try {
            $transferencia = $request->getRow()['transferencia'];
            $produto       = $request->getRow()['produtos'];

            $dataSet = $this->est57000transferenciaestoqueservice->salvarNovaTransferencia($transferencia,$produto);
            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function salvarNovoProduto(DTO\Request $request, DTO\Response $response) {
        try {
            $transferencia = $request->getRow()['transferencia'];
            $produto       = $request->getRow()['produtos'];

            $this->est57000transferenciaestoqueservice->salvarNovoProduto($transferencia,$produto);

        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function salvarNovaTransferenciaComRequisicao(DTO\Request$request, DTO\Response $response) {
        try {
            $transferencia = $request->getRow()['transferencia'];
            $itens = $request->getRow()["itens"];
            $dataSet = $this->est57000transferenciaestoqueservice->salvarNovaTransferenciaComRequisicao($transferencia, $itens);
            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function editarProdutoTransferencia(DTO\Request $request, DTO\Response $response) {
        try {
            $rows = $request->getRow();
            $dataSet = $this->est57000transferenciaestoqueservice->editProdutoTransferencia($rows);
            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function deletarProdutoTransferencia(DTO\Request $request, DTO\Response $response) {
        try {
            $rows = $request->getRow();
            $this->est57000transferenciaestoqueservice->deleteProduto($rows);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function deletarTransferencia(DTO\Request $request, DTO\Response $response) {
        try {
            $rows = $request->getRow();
            $this->est57000transferenciaestoqueservice->deleteTransferencia($rows);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function getAlmoxRequisicao(DTO\Request $request, DTO\Response $response) {
        try {
          $dataSet = $this->est57000transferenciaestoqueservice->getAlmoxRequisicao($request->getRow()['NRREQUESTO']);  
          $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
        
    }
    
     public function save(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName       = 'ctrlmoviestq_transferenciaEstoque';
        $this->dataSourceNameToSave = 'ctrlmoviestq_transferenciaEstoque';
        parent::save($request, $response);
    }

}